==> Notipyer-0.2.0.tar.gz: Notipyer-0.2.0/notipyer/email_notify.py <==
from .credential_handler import _set_email_credentials
from .utils.errors import GmailLoginException, RecipientNotPresentException
from .utils.async_decorator import Async
from notipyer import _get_creds
import smtplib

SMTP_GMAIL_URL = 'smtp.gmail.com'

mail_cred = _get_creds()


def _check_valid_string(string):
    if len(string) > 0:
        return True
    return False


def set_email_config(email, password):
    global mail_cred
    if _check_valid_string(email) and _check_valid_string(password):
        _set_email_credentials(mail_cred, email, password)


@Async
def send_email(subject, message, to_addr, cc_addr=None, bcc_addr=None):
    global mail_cred
    global SMTP_GMAIL_URL

    to_addr, cc_addr, bcc_addr = _check_recipients(to_addr, cc_addr, bcc_addr)

    client = smtplib.SMTP_SSL(SMTP_GMAIL_URL)
    client = _login_client(client)
    recipients, email_body = _build_email(subject, message, mail_cred.EMAIL_ID, to_addr, cc_addr, bcc_addr)
    client.sendmail(mail_cred.EMAIL_ID, recipients, email_body)
    client.quit()


def _login_client(client):
    try:
        client.login(mail_cred.EMAIL_ID, mail_cred.EMAIL_PASS)
        return client
    except smtplib.SMTPAuthenticationError:
        raise GmailLoginException()


def _check_recipients(to_addr, cc_addr, bcc_addr):
    if to_addr is None:
        to_addr = []
    if cc_addr is None:
        cc_addr = []
    if bcc_addr is None:
        bcc_addr = []

    if type(to_addr) is str:
        to_addr = [to_addr]
    if type(cc_addr) is str:
        cc_addr = [cc_addr]
    if type(bcc_addr) is str:
        bcc_addr = [bcc_addr]

    if len(to_addr + cc_addr + bcc_addr) < 1:
        raise RecipientNotPresentException()

    return to_addr, cc_addr, bcc_addr


def _build_email(subject, text, from_email, to_emails, cc_emails, bcc_emails):
    message = "From: %s\r\n" % from_email \
              + "To: %s\r\n" % ",".join(to_emails) \
              + "CC: %s\r\n" % ",".join(cc_emails) \
              + "Subject: %s\r\n" % subject \
              + "\r\n" \
              + text
    toaddrs = to_emails + cc_emails + bcc_emails
    return toaddrs, message

==> Notipyer-0.2.1.tar.gz: Notipyer-0.2.1/notipyer/email_notify.py <==
from .credential_handler import _set_email_credentials
from .utils.errors import GmailLoginException, RecipientNotPresentException
from .utils.async_decorator import Async
from notipyer import _get_creds
import smtplib

SMTP_GMAIL_URL = 'smtp.gmail.com'

mail_cred = _get_creds()


def _check_valid_string(string):
    if len(string) > 0:
        return True
    return False


def set_email_config(email, password, sender_name=''):
    global mail_cred
    if _check_valid_string(email) and _check_valid_string(password):
        _set_email_credentials(mail_cred, email, password, sender_name)


@Async
def send_email(subject, message, to_addr, cc_addr=None, bcc_addr=None):
    global mail_cred
    global SMTP_GMAIL_URL

    to_addr, cc_addr, bcc_addr = _check_recipients(to_addr, cc_addr, bcc_addr)

    client = smtplib.SMTP_SSL(SMTP_GMAIL_URL)
    client = _login_client(client)
    recipients, email_body = _build_email(subject, message, to_addr, cc_addr, bcc_addr)
    client.sendmail(mail_cred.EMAIL_ID, recipients, email_body)
    client.quit()


def _login_client(client):
    try:
        client.login(mail_cred.EMAIL_ID, mail_cred.EMAIL_PASS)
        return client
    except smtplib.SMTPAuthenticationError:
        raise GmailLoginException()


def _check_recipients(to_addr, cc_addr, bcc_addr):
    if to_addr is None:
        to_addr = []
    if cc_addr is None:
        cc_addr = []
    if bcc_addr is None:
        bcc_addr = []

    if type(to_addr) is str:
        to_addr = [to_addr]
    if type(cc_addr) is str:
        cc_addr = [cc_addr]
    if type(bcc_addr) is str:
        bcc_addr = [bcc_addr]

    if len(to_addr + cc_addr + bcc_addr) < 1:
        raise RecipientNotPresentException()

    return to_addr, cc_addr, bcc_addr


def _build_email(subject, text, to_emails, cc_emails, bcc_emails):
    global mail_cred
    if len(mail_cred.EMAIL_USER) > 0:
        sender = mail_cred.EMAIL_USER + ' <' + mail_cred.EMAIL_ID + '>'
    else:
        sender = mail_cred.EMAIL_ID
    message = "From: %s\r\n" % (sender) \
              + "To: %s\r\n" % ",".join(to_emails) \
              + "CC: %s\r\n" % ",".join(cc_emails) \
              + "Subject: %s\r\n" % subject \
              + "\r\n" \
              + text
    toaddrs = to_emails + cc_emails + bcc_emails
    return toaddrs, message
